import { value } from './main.js';

console.log('dynamic2', value);

export { value };
